# Task

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**brand** | **str** |  | [optional] 
**cloned_from** | **str** |  | [optional] 
**comment** | **str** |  | [optional] 
**conditions** | **list[str]** |  | [optional] 
**description** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**is_command** | **bool** |  | [optional] 
**is_locked** | **bool** |  | [optional] 
**is_system_task** | **bool** |  | [optional] 
**is_title_task** | **bool** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**playbook_id** | **str** |  | [optional] 
**script_id** | **str** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**tags** | **list[str]** |  | [optional] 
**type** | [**TaskType**](TaskType.md) |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


